#!/usr/bin/python
# -*- coding: latin-1 -*-

from ..connection import Connection
from ..utils import _make_url, _must_contain


class OrgaosClient(Connection):

    def listar_cargos_orgaos_legislativo(self):
        """
        Retorna a lista dos tipos de cargo para os rgos legislativos da Cmara dos Deputados (ex: presidente, primeiro-secretrio, etc)

        API ENDPOINT:
        http://www.camara.gov.br/SitCamaraWS/Orgaos.asmx/ListarCargosOrgaosLegislativosCD

        API DOC:
        http://www2.camara.leg.br/transparencia/dados-abertos/dados-abertos-legislativo/webservices/orgaos/listarcargosorgaoslegislativoscd

        This method does not have input parameters
        """

        return self.perform_request('http://www.camara.gov.br/SitCamaraWS/Orgaos.asmx/ListarCargosOrgaosLegislativosCD')

    def listar_tipos_orgaos(self):
        """
        Retorna a lista dos tipos de rgos que participam do processo legislativo na Cmara dos Deputados

        API ENDPOINT:
        http://www.camara.gov.br/SitCamaraWS/Orgaos.asmx/ListarTiposOrgaos

        API DOC:
        http://www2.camara.leg.br/transparencia/dados-abertos/dados-abertos-legislativo/webservices/orgaos/listartiposorgao

        This method does not have input parameters
        """

        return self.perform_request('http://www.camara.gov.br/SitCamaraWS/Orgaos.asmx/ListarTiposOrgaos')

    def obter_andamento(self,
                        sigla=None,
                        numero=None,
                        ano=None,
                        dataIni=None,
                        codOrgao=None):
        """
        Retorna o andamento de uma proposio pelos rgos internos da Cmara a partir de uma data especfica

        API ENDPOINT:
        http://www.camara.gov.br/SitCamaraWS/Orgaos.asmx/ObterAndamento?sigla=PL&numero=3962&ano=2008&dataIni=01/01/2009&codOrgao=

        API DOC:
        http://www2.camara.leg.br/transparencia/dados-abertos/dados-abertos-legislativo/webservices/orgaos/obterandamento

        Args:
            sigla:    String(Obrigatorio) :: Sigla do tipo de proposio
            numero:   Int(Obrigatorio)    :: Numero da proposio
            ano:      Int(Obrigatorio)    :: Ano da proposio
            dataIni:  String(Opcional)    :: Data a partir da qual as tramitaes do histrico de andamento sero retornadas (dd/mm/aaaa)
            codOrgao: String(Opcional)    :: ID do rgo numerador da proposio
        """
        base_url = 'http://www.camara.gov.br/SitCamaraWS/Orgaos.asmx/ObterAndamento?'
        params = dict([('sigla', sigla),
                       ('numero', numero),
                       ('ano', ano),
                       ('dataIni', dataIni),
                       ('codOrgao', codOrgao)])

        _must_contain(this=params, keys=['ano', 'numero', 'sigla'])

        return self.perform_request(_make_url(api_house='camara',
                                              base_url=base_url,
                                              params=params))

    def obter_emendas_substitutivo_redacao_final(self,
                                                 tipo=None,
                                                 ano=None,
                                                 numero=None):
        """
        Retorna as emendas, substitutivos e redaes finais de uma determinada proposio

        API ENDPOINT:
        http://www.camara.gov.br/SitCamaraWS/Orgaos.asmx/ObterEmendasSubstitutivoRedacaoFinal?tipo=PL&numero=3962&ano=2008

        API DOC:
        http://www2.camara.leg.br/transparencia/dados-abertos/dados-abertos-legislativo/webservices/orgaos/obteremendassubstitutivoredacaofinal

        Args:
            tipo:   String (Obrigatorio) :: Sigla do tipo de proposio
            ano:    Int (Obrigatorio) 	 :: Numero da proposio
            numero: Int (Obrigatorio) 	 :: Ano da proposio
        """

        base_url = 'http://www.camara.gov.br/SitCamaraWS/Orgaos.asmx/ObterEmendasSubstitutivoRedacaoFinal?'
        params = dict([('tipo', tipo),
                       ('numero', numero),
                       ('ano', ano)])

        _must_contain(this=params, keys=['ano', 'numero', 'tipo'])

        return self.perform_request(_make_url(api_house='camara',
                                              base_url=base_url,
                                              params=params))

    def obter_integra_comissoes_relator(self,
                                        tipo=None,
                                        ano=None,
                                        numero=None):
        """
        Retorna os dados de relatores e pareces, e o link para a ntegra de uma determinada proposio

        API ENDPOINT:
        http://www.camara.gov.br/SitCamaraWS/Orgaos.asmx/ObterIntegraComissoesRelator?tipo=PL&numero=3962&ano=2008

        API DOC:
        http://www2.camara.leg.br/transparencia/dados-abertos/dados-abertos-legislativo/webservices/orgaos/obterintegracomissoesrelator

        Args:
            tipo:   String (Obrigatorio) :: Sigla do tipo de proposio
            ano:    Int (Obrigatorio) 	 :: Numero da proposio
            numero: Int (Obrigatorio) 	 :: Ano da proposio
        """

        base_url = 'http://www.camara.gov.br/SitCamaraWS/Orgaos.asmx/ObterIntegraComissoesRelator?'
        params = dict([('tipo', tipo),
                       ('numero', numero),
                       ('ano', ano)])

        _must_contain(this=params, keys=['ano', 'numero', 'tipo'])

        return self.perform_request(_make_url(api_house='camara',
                                              base_url=base_url,
                                              params=params))



    def obter_membros_orgaos(self, idOrgao=None):
        """
        Retorna os parlamentares membros de uma determinada comisso

        API ENDPOINT:
        http://www.camara.gov.br/SitCamaraWS/Orgaos.asmx/ObterMembrosOrgao?IDOrgao=2004

        API DOC:
        http://www2.camara.leg.br/transparencia/dados-abertos/dados-abertos-legislativo/webservices/orgaos/obtermembrosorgao

        Args:
            idOrgao: Int (Obrigatorio)
        """

        base_url = 'http://www.camara.gov.br/SitCamaraWS/Orgaos.asmx/ObterMembrosOrgao?'
        params = dict([('idOrgao', idOrgao)])

        _must_contain(this=params, keys=['idOrgao'])

        return self.perform_request(_make_url(api_house='camara',
                                              base_url=base_url,
                                              params=params))
    def obter_orgaos(self):
        """
        Retorna a lista de rgos legislativos da Cmara dos Deputados (comisses, Mesa Diretora, conselhos, etc.)

        API ENDPOINT:
        http://www.camara.gov.br/SitCamaraWS/Orgaos.asmx/ObterOrgaos

        API DOC:
        http://www2.camara.leg.br/transparencia/dados-abertos/dados-abertos-legislativo/webservices/orgaos/obterorgaos

        This method does not have input parameters
        """

        return self.perform_request('http://www.camara.gov.br/SitCamaraWS/Orgaos.asmx/ObterOrgaos')

    def obter_pauta(self,
                    idOrgao=None,
                    dataIni=None,
                    dataFim=None):
        """
        Retorna as pautas das reunies de comisses e das sesses plenrias realizadas em um determinado perodo

        API ENDPOINT:
        http://www.camara.gov.br/SitCamaraWS/Orgaos.asmx/ObterPauta?IDOrgao=2004&datIni=01/01/2012&datFim=30/04/2012

        API DOC:
        http://www2.camara.leg.br/transparencia/dados-abertos/dados-abertos-legislativo/webservices/orgaos/obterpauta

        Args:
            idOrgao: Int(Obrigatorio) 	ID do rgo (comisso) da Cmara dos Deputados
            dataIni: String(Opcional) 	O mtoto retorna a pauta das reunies que foram realizadas em uma data maior ou igual a datIni
            dataFim: String(Opcional) 	O mtoto retorna a pauta das reunies que foram realizadas em uma data menor ou igual a datFim
        """

        base_url = 'http://www.camara.gov.br/SitCamaraWS/Orgaos.asmx/ObterPauta?'
        params = dict([('idOrgao', idOrgao),
                       ('dataIni', dataIni),
                       ('dataFim', dataFim)])

        _must_contain(this=params, keys=['idOrgao'])

        return self.perform_request(_make_url(api_house='camara',
                                              base_url=base_url,
                                              params=params))

    def obter_regime_tramitacao_despacho(self,
                                         tipo=None,
                                         numero=None,
                                         ano=None):
        """
        Retorna os dados do ltimo despacho da proposio

        API ENDPOINT:
        http://www.camara.gov.br/SitCamaraWS/Orgaos.asmx/ObterRegimeTramitacaoDespacho?tipo=PL&numero=8035&ano=2010

        API DOC:
        http://www2.camara.leg.br/transparencia/dados-abertos/dados-abertos-legislativo/webservices/orgaos/obterregimetramitacaodespacho

        Args:
            tipo:   String (Obrigatorio) ::	 Sigla do tipo de proposio
            numero: Int (Obrigatorio) 	 ::  Numero da proposio
            ano:    Int (Obrigatorio)    ::	 Ano da proposio
        """

        base_url = 'http://www.camara.gov.br/SitCamaraWS/Orgaos.asmx/ObterRegimeTramitacaoDespacho?'
        params = dict([('tipo', tipo),
                       ('numero', numero),
                       ('ano', ano)])

        _must_contain(this=params, keys=['tipo', 'ano', 'numero'])

        return self.perform_request(_make_url(api_house='camara',
                                              base_url=base_url,
                                              params=params))