#!/usr/bin/python
# -*- coding: latin-1 -*-
from ..connection import Connection
from ..utils import _make_url, _must_contain


class ProposicoesClient(Connection):

    def listar_proposicoes(self,
                           sigla=None,
                           ano=None,
                           numero=None,
                           datApresentacaoIni=None,
                           datApresentacaoFim=None,
                           idTipoAutor=None,
                           parteNomeAutor=None,
                           siglaPartidoAutor=None,
                           siglaUfAutor=None,
                           generoAutor=None,
                           codEstado=None,
                           codOrgaoEstado=None,
                           emTramitacao=None
                           ):
        """
        Retorna a lista de proposies que satisfaam os critrios estabelecidos

        API ENDPOINT:
        http://www.camara.gov.br/SitCamaraWS/Proposicoes.asmx/ListarProposicoes?sigla=PL&
(                                                                codEstado=&
                                                                                codOrgaoEstado=&
                                                                                emTramitacao=

        API DOC:
        http://www2.camara.leg.br/transparencia/dados-abertos/dados-abertos-legislativo/webservices/proposicoes-1/listarproposicoes

        Args:
            sigla: 	                    String(Obrigatorio se ParteNomeAutor no for preenchido) ::	Sigla do tipo de proposio
            ano: 	                    Int(Obrigatorio se ParteNomeAutor no for preenchido) 	 :: Ano da proposio

            numero: 	                Int(Obrigatorio)    :: Numero da proposio
            datApresentacaoIni: 	    Date(Opcional) 	 :: Menor data desejada para a data de apresentao da proposio.
                                                            Formato: DD/MM/AAAA
            datApresentacaoFim: 	    Date(Opcional) 	 :: Maior data desejada para a data de apresentao da proposio
                                                            Formato: DD/MM/AAAA
            idTipoAutor: 	            Int(Optional) 	 :: Identificador do tipo de rgo autor da proposio,
                                                            como obtido na chamada ao ListarTiposOrgao
            parteNomeAutor: 	        String(Optional) :: Parte do nome do autor(5 ou + caracteres) da proposio.
            siglaPartidoAutor: 	        String(Optional) :: Sigla do partido do autor da proposio
            siglaUfAutor: 	            String(Optional) :: UF de representao do autor da proposio
            generoAutor: 	            String(Optional) :: Gnero do autor<BR>M - Masculino; F - Feminino;
                                                            Default - Todos
            emTramitacao: 	            int(Opcional) 	 :: Indicador da situao de tramitao da proposio
                                                            1 - Em Tramitao no Congresso;
                                                            2- Tramitao Encerrada no Congresso;
                                                            Default - Todas
        """

        base_url = 'http://www.camara.gov.br/SitCamaraWS/Proposicoes.asmx/ListarProposicoes?'
        params = dict([('sigla', sigla),
                        ('ano', ano),
                        ('numero', numero),
                        ('datApresentacaoIni', datApresentacaoIni),
                        ('datApresentacaoFim', datApresentacaoFim),
                        ('idTipoAutor', idTipoAutor),
                        ('parteNomeAutor', parteNomeAutor),
                        ('siglaPartidoAutor', siglaPartidoAutor),
                        ('siglaUfAutor', siglaUfAutor),
                        ('generoAutor', generoAutor),
                        ('codEstado', codEstado),
                        ('codOrgaoEstado', codOrgaoEstado),
                        ('emTramitacao', emTramitacao)])

        try:
            _must_contain(params, ['parteNomeAutor'])
        except AttributeError:
            _must_contain(params, ['sigla', 'ano'])

        return self.perform_request(_make_url(api_house='camara',
                                              base_url=base_url,
                                              params=params))

    def listar_siglas_tipo_proposicao(self):
        """
        Retorna a lista de siglas de proposies

        API ENDPOINT:
        http://www.camara.gov.br/SitCamaraWS/Proposicoes.asmx/ListarSiglasTipoProposicao

        API DOC:
        http://www2.camara.leg.br/transparencia/dados-abertos/dados-abertos-legislativo/webservices/proposicoes-1/listarsiglastipoproposicao

        This method does not have input parameters
        """

        return self.perform_request('http://www.camara.gov.br/SitCamaraWS/Proposicoes.asmx/ListarSiglasTipoProposicao')

    def listar_situacoes_proposicao(self):
        """
        Retorna a lista de situaes para proposies

        API ENDPOINT:
        http://www.camara.gov.br/SitCamaraWS/Proposicoes.asmx/ListarSituacoesProposicao

        API DOC:
        http://www2.camara.leg.br/transparencia/dados-abertos/dados-abertos-legislativo/webservices/proposicoes-1/listarsituacoesproposicao

        This method does not have input parameters
        """

        return  self.perform_request('http://www.camara.gov.br/SitCamaraWS/Proposicoes.asmx/ListarSituacoesProposicao')

    def listar_tipos_autores(self):
        """
        Retorna a lista de situaes para proposies

        API ENDPOINT:
        http://www.camara.gov.br/SitCamaraWS/Proposicoes.asmx/ListarTiposAutores

        API DOC:
        http://www2.camara.leg.br/transparencia/dados-abertos/dados-abertos-legislativo/webservices/proposicoes-1/listartiposautores

        This method does not have input parameters
        """

        return self.perform_request('http://www.camara.gov.br/SitCamaraWS/Proposicoes.asmx/ListarTiposAutores')

    def obter_proposicao(self,
                         tipo=None,
                         ano=None,
                         numero=None,
                         idProp=None):
        """
        Retorna os dados de uma determinada proposio

        Grupo I
        API ENDPOINT:
        http://www.camara.gov.br/SitCamaraWS/Proposicoes.asmx/ObterProposicao?tipo=PL&numero=3962&ano=2008

        API DOC:
        http://www2.camara.leg.br/transparencia/dados-abertos/dados-abertos-legislativo/webservices/proposicoes-1/obterproposicao

        Grupo II
        API ENDPOINT:
        http://www.camara.gov.br/SitCamaraWS/Proposicoes.asmx/ObterProposicaoPorID?IdProp=354258

        API DOC:
        http://www2.camara.leg.br/transparencia/dados-abertos/dados-abertos-legislativo/webservices/proposicoes-1/obterproposicaoporid

        Args:
            Completar ou Grupo I ou Grupo II

            Grupo I
            tipo:   String (Obrigatorio) ::	Sigla do tipo de proposio
            ano:    Int (Obrigatorio) 	 :: Numero da proposio
            numero: Int (Obrigatorio) 	 :: Ano da proposio

            Grupo II
            idProp: Int (Obrigatorio)    ::	ID da proposio desejada
        """

        params = dict([('tipo', tipo),
                       ('ano', ano),
                       ('numero', numero),
                       ('idProp', idProp),
                       ])

        try:
            _must_contain(params, ['tipo', 'ano', 'numero'])
            base_url = 'http://www.camara.gov.br/SitCamaraWS/Proposicoes.asmx/ObterProposicao?'
            return self.perform_request(_make_url(api_house='camara',
                                                  base_url=base_url,
                                                  params=params))

        except AttributeError:
            _must_contain(params, ['idProp'])
            base_url = 'http://www.camara.gov.br/SitCamaraWS/Proposicoes.asmx/ObterProposicaoPorID?'
            return self.perform_request(_make_url(api_house='camara',
                                                  base_url=base_url,
                                                  params=params))



    def obter_proposicao_votacao(self,
                                 tipo=None,
                                 ano=None,
                                 numero=None):
        """
        Retorna os votos dos deputados a uma determinada proposio em votaes ocorridas no Plenrio da Cmara dos Deputados

        API ENDPOINT:
        http://www.camara.gov.br/SitCamaraWS/Proposicoes.asmx/ObterVotacaoProposicao?tipo=PL&numero=1992&ano=2007

        API DOC:
        http://www2.camara.leg.br/transparencia/dados-abertos/dados-abertos-legislativo/webservices/proposicoes-1/obtervotacaoproposicao

        Args:
            tipo:   String (Obrigatorio) ::	  Sigla do tipo de proposio
            ano:    Int (Obrigatorio) 	 ::   Numero da proposio
            numero: Int (Obrigatorio) 	 ::   Ano da proposio
        """
        base_url = 'http://www.camara.gov.br/SitCamaraWS/Proposicoes.asmx/ListarProposicoes?'
        params = dict([('tipo', tipo),
                       ('ano', ano),
                       ('numero', numero),
                       ])

        _must_contain(params, ['tipo', 'ano', 'numero'])

        return self.perform_request(_make_url(api_house='camara',
                                              base_url=base_url,
                                              params=params))

    def listar_proposicoes_votadas_em_plenario(self,
                                               ano=None,
                                               tipo=None):
        """
        Retorna a lista de proposies que sofreram votao em plenrio em determinado ano.

        API ENDPOINT:
        http://www.camara.gov.br/SitCamaraWS/Proposicoes.asmx/ListarProposicoesVotadasEmPlenario?ano=2013&tipo=

        API DOC:
        http://www2.camara.leg.br/transparencia/dados-abertos/dados-abertos-legislativo/webservices/proposicoes-1/ProposicoesVotadasEmPlenario

        Args:
            ano:  int(Obrigatorio) ::	Ano da proposio
            tipo: String(Opcional) ::	Tipo de proposio
        """

        base_url = 'http://www.camara.gov.br/SitCamaraWS/Proposicoes.asmx/ListarProposicoesVotadasEmPlenario?'
        params = dict([('tipo', tipo),
                       ('ano', ano),
                       ])

        _must_contain(params, ['ano'])

        return self.perform_request(_make_url(api_house='camara',
                                              base_url=base_url,
                                              params=params))

    def listar_proposicoes_tramitadas_no_periodo(self,
                                                 dtInicio=None,
                                                 dtFim=None):
        """
        Retorna lista de proposies que tramitaram em determinado perodo. O perodo mximo  de 7 dias

        API ENDPOINT:
        http://www.camara.gov.br/SitCamaraWS/Proposicoes.asmx/ListarProposicoesTramitadasNoPeriodo?dtInicio=20/09/2013&dtFim=21/09/2013

        API DOC:
        http://www2.camara.leg.br/transparencia/dados-abertos/dados-abertos-legislativo/webservices/proposicoes-1/listarProposicoesTramitadasNoPeriodo

        Args:
            dtInicio: String (Obrigatorio) ::	Data de incio
            dtFim:    String (Obrigatorio) ::	Data final
        """
        base_url = 'http://www.camara.gov.br/SitCamaraWS/Proposicoes.asmx/ListarProposicoesTramitadasNoPeriodo?'
        params = dict([('dtInicio', dtInicio),
                       ('dtFim', dtFim)])

        _must_contain(params, ['dtInicio', 'dtFim'])

        return self.perform_request(_make_url(api_house='camara',
                                              base_url=base_url,
                                              params=params))